Action class

Implementers

Constructors

Action({required String method, required String paramsJson, bool? optional = false})
const
Action.create({required String method, required Map<String, dynamic> params, bool optional = false})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → String
final
optional → bool?
final
paramsJson → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited