Configuration class

Constructors

Configuration({required IOSConfiguration? ios, required AndroidConfiguration? android})

Properties

android → AndroidConfiguration?
final
hashCode → int
The hash code for this object.
no setterinherited
ios → IOSConfiguration?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited