AddEthereumChain class

Inheritance

Constructors

AddEthereumChain({required String chainId, required List<String> rpcUrls, String? chainName, Currency? nativeCurrency, List<String>? iconUrls, List<String>? blockExplorerUrls})

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → String
finalinherited
optional → bool?
finalinherited
paramsJson → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited