SignTransaction class

Inheritance

Constructors

SignTransaction({required String fromAddress, required String chainId, String? toAddress, BigInt? weiValue, String? data, int? nonce, BigInt? gasPriceInWei, BigInt? maxFeePerGas, BigInt? maxPriorityFeePerGas, BigInt? gasLimit})

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → String
finalinherited
optional → bool?
finalinherited
paramsJson → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited